Retain Touch — Kivy v1.0.1-dev documentation

# Retain Touch

Reuse touch to counter finger lost behavior

class `kivy.input.postproc.retaintouch.` `InputPostprocRetainTouch`

  Bases: `object`

  InputPostprocRetainTouch is a post-processor to delay the ‘up’ event of a touch, to reuse it under certains conditions. This module is designed to prevent finger lost on some hardware/setup.

  Retain touch can be configured in the Kivy config file

      [postproc]
          retain_time = 100
          retain_distance = 50

  Distance parameter is in 0-1000, and time is in millisecond.